@@ -40,10 +40,10 @@ crew_launcher_slurm <- function(
   seconds_wall = Inf,
   tasks_max = Inf,
   tasks_timers = 0L,
-  reset_globals = TRUE,
-  reset_packages = FALSE,
-  reset_options = FALSE,
-  garbage_collection = FALSE,
+  reset_globals = NULL,
+  reset_packages = NULL,
+  reset_options = NULL,
+  garbage_collection = NULL,
   crashes_error = NULL,
   tls = crew::crew_tls(mode = "automatic"),
   r_arguments = c("--no-save", "--no-restore"),
