@@ -3,8 +3,10 @@ test_that("PBS minimal", {
     name = "my_workflow",
     workers = 1L,
     seconds_idle = 300,
-    script_lines = paste0("module load R/", getRversion()),
-    verbose = TRUE
+    options_cluster = crew_options_pbs(
+      script_lines = paste0("module load R/", getRversion()),
+      verbose = TRUE
+    )
   )
   on.exit(controller$terminate())
   controller$start()
