@@ -39,3 +39,18 @@ test_that("crew_controller_lsf() script() all lines", {
   )
   expect_equal(out, exp)
 })
+
+# https://github.com/wlandau/crew/issues/217
+test_that("crew_controller_lsf() cleanup deprecations", {
+  x <- crew_controller_lsf()
+  fields <- c(
+    "reset_globals",
+    "reset_packages",
+    "reset_globals",
+    "garbage_collection"
+  )
+  for (field in fields) {
+    expect_true(is.logical(x[[field]]))
+    expect_null(x$launcher[[field]])
+  }
+})
